"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.OpQueue = void 0;
/**
 * Queue used for serializing BLE operations.
 */
class OpQueue {
    /**
     * Create the queue.
     */
    constructor() {
        this._current = Promise.resolve();
    }
    /**
     * Queue a new operation.
     *
     * @param {function} op - Function to queue
     * @returns {Promise} Promise which resolves when the function has executed.
     */
    queue(op) {
        const ret = new Promise((resolve, reject) => {
            this._current.then(() => {
                op().then(resolve, reject);
            });
        });
        // eslint-disable-next-line @typescript-eslint/no-empty-function
        this._current = ret.catch(() => { });
        return ret;
    }
}
exports.OpQueue = OpQueue;
//# sourceMappingURL=queue.js.map